@@ -36,7 +36,7 @@ def CreateGenerator(filepath, subfolder, param, want=None, count=-1, train_test_
         raise Exception('train_test_predict parameter must be 0 (training), 1 (testing), or 2 (predicting).')
 
     # create generator object
-    dataGenerator = HPinputGenerator(S_half = param['S_half'], \
+    dataGenerator = HPinputGenerator(S_half = param['s_half'], \
                                       batch_size = param['batch_size'],\
                                       scales=param['scales'], \
                                       scalefactor=param['scalefactor'], \
@@ -89,12 +89,12 @@ def CreateGenerator(filepath, subfolder, param, want=None, count=-1, train_test_
     # if there are masks and track_outies flag is true, alert user and invert masks
     if param['track_outies'] and np.sum([not m is None for m in masks])>0:
         if chatter:
-            print('Inverting masks to track zero-valued pixels.')
+            print('[BB] -- Inverting masks to track zero-valued pixels.')
         masks = [1*(m == 0) if (not m is None) else None for m in masks]
     
     # create HP inputs
     for k,img in enumerate(imgs):
-        dataGenerator.add_ID_img(img, mask=masks[k], AOI=AOIs[k], neighborhood_radius=param['HP_neighborhood_radius'], particle_border_mult=param['HP_particle_border_mult'], two_particle_mult=param['HP_two_particle_mult'],  img_edge_mult = param['HP_img_edge_mult'])                   
+        dataGenerator.add_ID_img(img, mask=masks[k], AOI=AOIs[k], neighborhood_radius=param['border_radius'], particle_border_mult=param['particle_border_weighting'], two_particle_mult=param['two_particle_border_weighting'],  img_edge_mult = param['image_border_weighting'])                   
 
     return dataGenerator, img_names, copy.deepcopy(masks)
 
@@ -339,7 +339,7 @@ class BBinputGenerator(tf.keras.utils.Sequence):
     # returns max and minimum value of all images
     def get_img_range(self):
         maxval,minval = np.max(self.get_img(0)),np.min(self.get_img(0))
-        for idx in range(1,np.shape(self.imgs)[0]):
+        for idx in range(1,len(self.imgs)):
             maxval = np.max([maxval,np.max(self.get_img(idx))])
             minval = np.min([minval,np.min(self.get_img(idx))])
         
